==> owncloud_6.0.4~beta1%2Bdfsg.orig.tar.bz2: owncloud/apps/contacts/l10n/ca.php <==
<?php $TRANSLATIONS = array(
"Contacts" => "Contactes",
"Save" => "Desa",
"Uploading..." => "Pujant...",
"Importing..." => "Important...",
"Preparing..." => "Preparant...",
"Imported {count} of {total} contacts" => "S'han importat {count} de {total} contactes",
"Imported {imported} contacts. {failed} failed." => "S'han importat {imported} contactes. {failed} han fallat.",
"An address book called {name} already exists" => "Ja existeix una llibreta d'adreces amb el nom {name} ",
"Failed adding address book: {error}" => "Ha fallat en afegir la llibreta d'adreces: {error}",
"Failed loading address books: {error}" => "Ha fallat en carregar llibretes d'adreces: {error}",
"Indexing contacts" => "Indexant contactes",
"Unrecoverable error loading address books: {msg}" => "Error irrecuperable en carregar llibretes d'adreces: {msg}",
"Error." => "Error.",
"Add to..." => "Afegeix a...",
"Remove from..." => "Elimina des de...",
"Add group..." => "Afegeix grup...",
"Invalid URL: \"{url}\"" => "URL no vàlida: \"{url}\"",
"There was an error opening a mail composer." => "S'ha produït un error en obrir un redactor de correus electrónics.",
"Invalid email: \"{url}\"" => "Correu electrònic no vàlid: \"{url}\"",
"Merge failed. Cannot find contact: {id}" => "La combinació ha fallat. No es pot trobar el contacte: {id}",
"Merge failed." => "La combinació ha fallat.",
"Merge failed. Error saving contact." => "La combinació ha fallat. Error en desar el contacte.",
"Select photo" => "Selecciona una foto",
"Network or server error. Please inform administrator." => "Error de xarxa o del servidor. Informeu a l'administrador.",
"Error adding to group." => "Error en afegir grup",
"Error removing from group." => "Error en eliminar del grup",
"Error setting {name} as favorite." => "Error en establir {name} com a preferit.",
"Merge contacts" => "Combina contactes",
"Cancel" => "Cancel·la",
"Add group" => "Afegeix grup",
"OK" => "D'acord",
"Could not find contact: {id}" => "El contacte no s'ha trobat: {id}",
"No files selected for upload." => "No s'han seleccionat fitxers per a la pujada.",
"The file you are trying to upload exceed the maximum size for file uploads on this server." => "El fitxer que intenteu pujar excedeix la mida màxima de pujada en aquest servidor.",
"Edit profile picture" => "Edita la fotografia de perfil",
"Crop photo" => "Talla la fotografia",
"Is this correct?" => "És correcte?",
"Error parsing date: {date}" => "Error en processar la data: {date}",
"# groups" => "# grups",
"Error parsing birthday {bday}: {error}" => "Error en processar l'aniversari {bday}: {error}",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "Heu marcat eliminar alguns contactes, però encara no s'han eliminat. Espereu mentre s'esborren.",
"Click to undo deletion of {num} contacts" => "Feu clic a desfés eliminació de {num} contactes",
"Cancelled deletion of {num} contacts" => "Cancel·la l'eliminació de {num} contactes",
"Add" => "Afegeix",
"Contact is already in this group." => "El contacte ja és en aquest grup.",
"Contacts are already in this group." => "Els contactes ja són en aquest grup",
"Couldn't get contact list." => "No s'ha pogut obtenir la llista de contactes.",
"Contact is not in this group." => "El contacte no és en aquest grup.",
"Contacts are not in this group." => "Els contactes no són en aquest grup.",
"Failed renaming group: {error}" => "Ha fallat en canviar el nom del grup: {error}",
"A group named {group} already exists" => "Un grup anomenat {group} ja existeix",
"You can drag groups to\narrange them as you like." => "Podeu arrossegar grups per\norganitzar-los com volgueu.",
"Failed adding group: {error}" => "Ha fallat en afegir el grup: {error}",
"All" => "Tots",
"Favorites" => "Preferits",
"Shared by {owner}" => "Compartits per {owner}",
"Not grouped" => "Sense grup",
"Failed loading groups: {error}" => "Ha fallat en carregar grups: {error}",
"Please choose the addressbook" => "Escolliu la llibreta d'adreces",
"Import into..." => "Importa a...",
"Error loading import template" => "Error en carregar la plantilla d'importació",
"Import contacts" => "Importa contactes",
"Import" => "Importa",
"Import done" => "S'ha importat",
"Close" => "Tanca",
"Error" => "Error",
"Displayname cannot be empty." => "El nom a mostrar no pot ser buit",
"Show CardDav link" => "Mostra l'enllaç CardDav",
"Show read-only VCF link" => "Mostra l'enllaç VCF només de lectura",
"Download" => "Baixa",
"Edit" => "Edita",
"Delete" => "Esborra",
"More..." => "Més...",
"Less..." => "Menys...",
"Server error! Please inform system administator" => "Error en el servidor! Informeu a l'administrador del sistema",
"Failed loading photo: {error}" => "Ha fallat en carregar la foto: {error}",
"You do not have permissions to see this contacts" => "No teniu permisos per veure aquest contacte",
"Contact not found" => "El contacte no s'ha trobat",
"You do not have permissions to see these contacts" => "No teniu permisos per veure aquests contactes",
"You do not have permissions add contacts to the address book" => "No teniu permisos per afegir contactes a la llibreta d'adreces",
"The backend for this address book does not support adding contacts" => "El dorsal per aquesta llibreta d'adreces no permet afegir contactes",
"You do not have permissions to delete this contact" => "No teniu permisos per eliminar aquest contacte",
"The backend for this address book does not support deleting contacts" => "El dorsal d'aquesta llibreta d'adreces no permet esborrar contactes",
"Unknown error" => "Error desconegut",
"The backend for this address book does not support updating" => "El dorsal d'aquesta llibreta d'adreces no permet actualitzacions",
"You don't have permissions to update the address book." => "No teniu permisos per actualitzar la llibreta d'adreces.",
"You don't have permissions to delete the address book." => "No teniu permisos per esborar la llibreta d'adreces.",
"Address book not found" => "No s'han trobat llibretes d'adreces.",
"You do not have permissions to see this contact" => "No teniu permisos per veure aquest contacte",
"You do not have permissions to update this contact" => "No teniu permisos per actualitzar aquest contacte",
"The backend for this contact does not support updating it" => "El dorsal d'aquest contacte no permet actualitzar-lo",
"This backend not support adding contacts" => "Aquest dorsal no permet afegir contactes",
"Property not found" => "La propietat no s'ha trobat",
" Missing IM parameter for: " => "Falta un paràmetre de MI per a:",
"Unknown IM: " => "IM desconegut:",
"{name}'s Birthday" => "Aniversari de {name}",
"Error creating address book" => "Error en crear la llibreta d'adreces",
"Error updating address book" => "Error en actualitzar la llibreta d'adreces",
"You do not have permissions to delete the \"%s\" address book" => "No teniu permisos per esborar la llibreta d'adreces \"%s\".",
"Error deleting address book" => "Error en eliminar la llibreta d'adreces",
"Error creating contact." => "Error en crear contacte.",
"Error deleting contact." => "Error en eliminar contacte.",
"Error retrieving contact." => "Error en obtenir el contacte.",
"Error saving contact." => "Error en desar el contacte.",
"Error removing contact from other address book." => "Error en eliminar el contacte des d'una altra llibreta d'adreces.",
"Couldn't find contact." => "El contacte no s'ha trobat.",
"No contact data in request." => "No hi ha dades de contacte en la sol·licitud.",
"Error merging into contact." => "Error en combinar en el contacte.",
"Error saving contact to backend." => "Error en desar el contacte en el dorsal.",
"Property name is not set." => "La propietat nom no està definida.",
"Property checksum is not set." => "La suma de verificació no està definida.",
"Information about vCard is incorrect. Please reload the page." => "La informació de la vCard és incorrecta. Carregueu la pàgina de nou.",
"Error updating contact" => "Error en actualitzar el contacte",
"Error saving contact to backend" => "Error en desar el contacte en el dorsal",
"Error getting user photo" => "Error en obtenir la fotografia d'usuari.",
"No file was uploaded. Unknown error" => "No s'ha carregat cap fitxer. Error desconegut",
"There is no error, the file uploaded with success" => "No hi ha errors, el fitxer s'ha carregat correctament",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "El fitxer carregat supera la directiva upload_max_filesize de php.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "El fitxer carregat supera la directiva MAX_FILE_SIZE especificada al formulari HTML",
"The uploaded file was only partially uploaded" => "El fitxer només s'ha carregat parcialment",
"No file was uploaded" => "No s'ha carregat cap fitxer",
"Missing a temporary folder" => "Falta un fitxer temporal",
"Couldn't load temporary image: " => "No s'ha pogut carregar la imatge temporal: ",
"Couldn't save temporary image: " => "No s'ha pogut desar la imatge temporal: ",
"No photo path was submitted." => "No heu tramès el camí de la foto.",
"File doesn't exist:" => "El fitxer no existeix:",
"Error loading image." => "Error en carregar la imatge.",
"Image has been removed from cache" => "La imatge s'ha eliminat de la memòria de cau",
"Error creating temporary image" => "Error en crear la imatge temporal",
"Error cropping image" => "Error en retallar la imatge",
"Error resizing image" => "Error en modificar la mida de la imatge",
"Error getting PHOTO property." => "Error en obtenir la propietat PHOTO.",
"No group name given." => "No heu facilitat el nom de cap grup.",
"Error adding group." => "Error en afegir grup.",
"No group name to rename from given." => "No heu facilitat cap nom de grup per canviar-li el nom.",
"No group name to rename to given." => "No heu facilitat el nom de grup per canviar-li el nom.",
"Error renaming group." => "Error en canviar el nom del grup.",
"Group ID missing from request." => "La ID del grup s'ha perdut en el requeriment.",
"Group name missing from request." => "Al requeriment li falta el nom del grup.",
"Contact ID missing from request." => "La ID del contacte s'ha perdut en el requeriment.",
"Failed to write to disk" => "Ha fallat en escriure al disc",
"Not enough storage available" => "No hi ha prou espai disponible",
"Attempt to upload blacklisted file:" => "Intent de pujar un fitxer de la llista negra:",
"Error uploading contacts to storage." => "Error en carregar contactes a l'emmagatzemament.",
"Error moving file to imports folder." => "Error en moure el fitxer a la carpeta d'importació.",
"You do not have permissions to import into this address book." => "No teniu permisos per importar dins d'aquesta llibreta d'adreces.",
"File name missing from request." => "Falta el nom del fitxer en la petició.",
"Progress key missing from request." => "Falta la clau de progrés en la petició.",
"Attempt to access blacklisted file:" => "Intent d'accés a un fitxer de la llista negra:",
"No contacts found in: " => "No s'han trobat contactes a:",
"No key is given." => "No heu facilitat cap clau.",
"No value is given." => "No heu facilitat cap valor.",
"Could not set preference: " => "No s'ha pogut establir la preferència:",
"Contact" => "Contacte",
"Other" => "Un altre",
"HomePage" => "Pàgina d'inici",
"Jabber" => "Jabber",
"Internet call" => "Trucada d'Internet",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Twitter",
"GoogleTalk" => "GoogleTalk",
"Facebook" => "Facebook",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"Work" => "Feina",
"Home" => "Casa",
"Mobile" => "Mòbil",
"Text" => "Text",
"Voice" => "Veu",
"Message" => "Missatge",
"Fax" => "Fax",
"Video" => "Vídeo",
"Pager" => "Paginador",
"Internet" => "Internet",
"Friends" => "Amics",
"Family" => "Familia",
"New Contact" => "Contate nou",
"Group name" => "Nom del grup",
"New Group" => "Grup nou",
"Address books" => "Llibretes d'adreces",
"Display name" => "Nom a mostrar",
"Add Address Book" => "Afegeix una llibreta d'adreces",
"Select file..." => "Selecciona un fitxer...",
"(De-)select all" => "(Des-)selecciona'ls tots",
"Sort order" => "Ordena",
"First- Lastname" => "Nom- Congnom",
"Last-, Firstname" => "Cognom-, Nom",
"Groups" => "Grups",
"Favorite" => "Preferits",
"Merge selected" => "Combina els seleccionats",
"Keyboard shortcuts" => "Dreceres de teclat",
"Navigation" => "Navegació",
"Next contact in list" => "Següent contacte de la llista",
"Previous contact in list" => "Contacte anterior de la llista",
"Expand/collapse current addressbook" => "Expandeix/col·lapsa la llibreta d'adreces",
"Next addressbook" => "Llibreta d'adreces següent",
"Previous addressbook" => "Llibreta d'adreces anterior",
"Actions" => "Accions",
"Refresh contacts list" => "Carrega de nou la llista de contactes",
"Add new contact" => "Afegeix un contacte nou",
"Add new addressbook" => "Afegeix una llibreta d'adreces nova",
"Delete current contact" => "Esborra el contacte",
"<h3>You have no contacts in your address book or your address book is disabled.</h3><p>Add a new contact or import existing contacts from a VCF file.</p>" => "<h3>No teniu contactes a la vostra llibreta d'adreces o la vostra llibreta d'adreces està inhabilitada.</h3><p>Afegiu un nou contacte o importeu-ne d'existents des d'un fitxer VCF.</p>",
"Add contact" => "Afegeix un contacte",
"Delete group" => "Elimina grup",
"Rename group" => "Canvia el nom del grup",
"Which contact should the data be merged into?" => "A quin contacte li voleu combinar les dades?",
"Delete the other(s) after successful merge?" => "Elimino els altre(s) després d'una combinació satisfactòria?",
"Compose mail" => "Redacta un correu electrónic",
"Delete current photo" => "Elimina la foto actual",
"Edit current photo" => "Edita la foto actual",
"Upload new photo" => "Carrega una foto nova",
"Select photo from ownCloud" => "Selecciona una foto de ownCloud",
"Name" => "Nom",
"First name" => "Nom",
"Additional names" => "Noms addicionals",
"Last name" => "Cognom",
"Select groups" => "Selecciona els grups",
"Select address book" => "Selecciona la llibreta d'adreces",
"Nickname" => "Sobrenom",
"Enter nickname" => "Escriviu el sobrenom",
"Title" => "Títol",
"Enter title" => "Escriviu el títol",
"Organization" => "Organització",
"Enter organization" => "Escriviu l'organització",
"Birthday" => "Aniversari",
"Notes go here..." => "Escriviu notes aquí...",
"Export as VCF" => "Exporta com a VCF",
"Add field..." => "Afegeix camp...",
"Phone" => "Telèfon",
"Email" => "Correu electrònic",
"Instant Messaging" => "Missatgeria instantània",
"Address" => "Adreça",
"Note" => "Nota",
"Web site" => "Adreça web",
"Delete contact" => "Suprimeix el contacte",
"Preferred" => "Preferit",
"Please specify a valid email address." => "Especifiqueu una adreça de correu electrònic correcta",
"someone@example.com" => "algú@exemple.com",
"Mail to address" => "Envia per correu electrònic a l'adreça",
"Delete email address" => "Elimina l'adreça de correu electrònic",
"Enter phone number" => "Escriviu el número de telèfon",
"Delete phone number" => "Elimina el número de telèfon",
"Go to web site" => "Vés a la web",
"Delete URL" => "Elimina URL",
"View on map" => "Visualitza al mapa",
"Delete address" => "Elimina l'adreça",
"1600 Pennsylvania Avenue, NW" => "Carrer del pi, 32 2n 1a",
"Street address" => "Adreça",
"20500" => "08080",
"Postal code" => "Codi postal",
"Washington, DC" => "Barcelona",
"City" => "Ciutat",
"District of Columbia" => "Comarca del Bercelonès",
"State or province" => "Estat o província",
"USA" => "Catalunya",
"Country" => "País",
"Instant Messenger" => "Instant Messenger",
"Delete IM" => "Elimina IM",
"Active" => "Actiu",
"Share" => "Comparteix",
"Export" => "Exporta",
"CardDAV link" => "Enllaç CardDAV",
"CardDAV syncing addresses" => "Adreces de sincronització CardDAV",
"more info" => "més informació",
"Primary address (Kontact et al)" => "Adreça primària (Kontact et al)",
"iOS/OS X" => "IOS/OS X",
"Addressbooks" => "Llibretes d'adreces",
"New Address Book" => "Nova llibreta d'adreces",
"Description" => "Descripció"
);

==> owncloud_7.0.0~beta1%2Bdfsg.orig.tar.bz2: owncloud/apps/contacts/l10n/ca.php <==
<?php $TRANSLATIONS = array(
"Contacts" => "Contactes",
"Add new LDAP Addressbook" => "Afegeix una llibreta d'adreces LDAP nova",
"Ok" => "D'acord",
"Cancel" => "Cancel·la",
"Save" => "Desa",
"Edit Addressbook" => "Edita la llibreta d'adreces",
"Starting file import" => "Iniciant la importació del fitxer",
"Format selected: {format}" => "Format seleccionat: {format}",
"Automatic format detection" => "Detecció automàtica del format",
"Processing {count}/{total} cards" => "Processant contactes {count}/{total}",
"Total:{total}, Success:{imported}, Errors:{failed}" => "Total:{total}, Amb èxit:{imported}, Errors:{failed}",
"An address book called {name} already exists" => "Ja existeix una llibreta d'adreces amb el nom {name} ",
"Failed adding address book: {error}" => "Ha fallat en afegir la llibreta d'adreces: {error}",
"Failed loading address books: {error}" => "Ha fallat en carregar llibretes d'adreces: {error}",
"Server error! Please inform system administator" => "Error en el servidor! Informeu a l'administrador del sistema",
"Indexing contacts" => "Indexant contactes",
"Unrecoverable error loading address books: {msg}" => "Error irrecuperable en carregar llibretes d'adreces: {msg}",
"Error." => "Error.",
"Add to..." => "Afegeix a...",
"Remove from..." => "Elimina des de...",
"Add group..." => "Afegeix grup...",
"Invalid URL: \"{url}\"" => "URL no vàlida: \"{url}\"",
"Invalid email: \"{url}\"" => "Correu electrònic no vàlid: \"{url}\"",
"Merge failed. Cannot find contact: {id}" => "La combinació ha fallat. No es pot trobar el contacte: {id}",
"Merge failed." => "La combinació ha fallat.",
"Merge failed. Error saving contact." => "La combinació ha fallat. Error en desar el contacte.",
"Select photo" => "Selecciona una foto",
"Network or server error. Please inform administrator." => "Error de xarxa o del servidor. Informeu a l'administrador.",
"Only images can be used as contact photos" => "Només es poden utilitzar imatges com a fotos de contacte",
"The size of \"{filename}\" exceeds the maximum allowed {size}" => "El fitxer \"{filename}\" excedeix el pes màxim permès {size}",
"Error adding to group." => "Error en afegir grup",
"Error removing from group." => "Error en eliminar del grup",
"You have selected over 300 contacts.\nThis will most likely fail! Click here to try anyway." => "Heu seleccionat més de 300 contactes.\nAixò segurament fallarà!  Feu clic aquí per provar-ho igualment.",
"Error setting {name} as favorite." => "Error en establir {name} com a preferit.",
"Merge contacts" => "Combina contactes",
"Add group" => "Afegeix grup",
"OK" => "D'acord",
"Could not find contact: {id}" => "El contacte no s'ha trobat: {id}",
"Edit profile picture" => "Edita la fotografia de perfil",
"Crop photo" => "Talla la fotografia",
"Error parsing date: {date}" => "Error en processar la data: {date}",
"# groups" => "# grups",
"Error parsing birthday {bday}" => "Error en processar l'aniversari {bday}",
"The backend does not support multi-byte characters." => "El backend no admet caràcters multi-byte.",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "Heu marcat eliminar alguns contactes, però encara no s'han eliminat. Espereu mentre s'esborren.",
"Click to undo deletion of {num} contacts" => "Feu clic a desfés eliminació de {num} contactes",
"Cancelled deletion of {num} contacts" => "Cancel·la l'eliminació de {num} contactes",
"Add" => "Afegeix",
"Contact is already in this group." => "El contacte ja és en aquest grup.",
"Contacts are already in this group." => "Els contactes ja són en aquest grup",
"Couldn't get contact list." => "No s'ha pogut obtenir la llista de contactes.",
"Contact is not in this group." => "El contacte no és en aquest grup.",
"Contacts are not in this group." => "Els contactes no són en aquest grup.",
"A group named \"{group}\" already exists" => "Ja hi ha un grup amb el nom \"{group}\"",
"Failed renaming group: {error}" => "Ha fallat en canviar el nom del grup: {error}",
"You can drag groups to\narrange them as you like." => "Podeu arrossegar grups per\norganitzar-los com volgueu.",
"Failed adding group: {error}" => "Ha fallat en afegir el grup: {error}",
"All" => "Tots",
"Favorites" => "Preferits",
"Shared by {owner}" => "Compartits per {owner}",
"Not grouped" => "Sense grup",
"Failed loading groups: {error}" => "Ha fallat en carregar grups: {error}",
"Please choose the addressbook" => "Escolliu la llibreta d'adreces",
"Import into..." => "Importa a...",
"Error loading import template" => "Error en carregar la plantilla d'importació",
"Import contacts" => "Importa contactes",
"Import" => "Importa",
"Importing..." => "Important...",
"Import done" => "S'ha importat",
"Close" => "Tanca",
"Error, missing parameters: " => "Error, falten paràmetres:",
"Failed loading photo: {error}" => "Ha fallat en carregar la foto: {error}",
"You do not have permissions to see this contact" => "No teniu permisos per veure aquest contacte",
"Contact not found" => "El contacte no s'ha trobat",
"You do not have permissions to see these contacts" => "No teniu permisos per veure aquests contactes",
"You do not have permissions add contacts to the address book" => "No teniu permisos per afegir contactes a la llibreta d'adreces",
"The backend for this address book does not support adding contacts" => "El dorsal per aquesta llibreta d'adreces no permet afegir contactes",
"You do not have permissions to delete this contact" => "No teniu permisos per eliminar aquest contacte",
"The backend for this address book does not support deleting contacts" => "El dorsal d'aquesta llibreta d'adreces no permet esborrar contactes",
"Unknown error" => "Error desconegut",
"Access denied" => "Accés denegat",
"The backend for this address book does not support updating" => "El dorsal d'aquesta llibreta d'adreces no permet actualitzacions",
"You don't have permissions to delete the address book." => "No teniu permisos per esborar la llibreta d'adreces.",
"Address book not found" => "No s'han trobat llibretes d'adreces.",
"You do not have permissions to update this contact" => "No teniu permisos per actualitzar aquest contacte",
"The backend for this contact does not support updating it" => "El dorsal d'aquest contacte no permet actualitzar-lo",
"This backend does not support adding contacts" => "Aquest rerefons no permet afegir contactes",
"Property not found" => "La propietat no s'ha trobat",
" Missing IM parameter for: " => "Falta un paràmetre de MI per a:",
"Unknown IM: " => "IM desconegut:",
"{name}'s Birthday" => "Aniversari de {name}",
"Error creating address book" => "Error en crear la llibreta d'adreces",
"The \"%s\" backend does not support deleting address books" => "El backend \"%s\" no admet l'eliminació de les agendes",
"You do not have permissions to delete the \"%s\" address book" => "No teniu permisos per esborar la llibreta d'adreces \"%s\".",
"Error deleting address book" => "Error en eliminar la llibreta d'adreces",
"Error creating contact." => "Error en crear contacte.",
"Error creating contact" => "Error al crear un contacte",
"Error deleting contact" => "Error al esborra un contacte",
"Error retrieving contact" => "Error al recuperar un contacte",
"Error saving contact" => "Error guardant un contacte",
"Error removing contact from other address book." => "Error en eliminar el contacte des d'una altra llibreta d'adreces.",
"Error getting moved contact" => "Error al traslladar un contacte",
"Couldn't find contact." => "El contacte no s'ha trobat.",
"No contact data in request." => "No hi ha dades de contacte en la sol·licitud.",
"Error merging into contact." => "Error en combinar en el contacte.",
"Error saving contact to backend." => "Error en desar el contacte en el dorsal.",
"Property name is not set." => "La propietat nom no està definida.",
"Property checksum is not set." => "La suma de verificació no està definida.",
"Information about vCard is incorrect. Please reload the page." => "La informació de la vCard és incorrecta. Carregueu la pàgina de nou.",
"Error updating contact" => "Error en actualitzar el contacte",
"Error saving contact to backend" => "Error en desar el contacte en el dorsal",
"Error getting user photo" => "Error en obtenir la fotografia d'usuari.",
"No photo path was submitted." => "No heu tramès el camí de la foto.",
"Error loading image from cache" => "Error en carregar la imatge de la memòria cau",
"Error getting PHOTO property." => "Error en obtenir la propietat PHOTO.",
"Error saving contact." => "Error en desar el contacte.",
"No group name given." => "No heu facilitat el nom de cap grup.",
"Error adding group." => "Error en afegir grup.",
"No group name to rename from given." => "No heu facilitat cap nom de grup per canviar-li el nom.",
"No group name to rename to given." => "No heu facilitat el nom de grup per canviar-li el nom.",
"Error renaming group." => "Error en canviar el nom del grup.",
"Group ID missing from request." => "La ID del grup s'ha perdut en el requeriment.",
"Group name missing from request." => "Al requeriment li falta el nom del grup.",
"Contact ID missing from request." => "La ID del contacte s'ha perdut en el requeriment.",
"No file was uploaded. Unknown error" => "No s'ha carregat cap fitxer. Error desconegut",
"There is no error, the file uploaded with success" => "No hi ha errors, el fitxer s'ha carregat correctament",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "El fitxer carregat supera la directiva upload_max_filesize de php.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "El fitxer carregat supera la directiva MAX_FILE_SIZE especificada al formulari HTML",
"The uploaded file was only partially uploaded" => "El fitxer només s'ha carregat parcialment",
"No file was uploaded" => "No s'ha carregat cap fitxer",
"Missing a temporary folder" => "Falta un fitxer temporal",
"Failed to write to disk" => "Ha fallat en escriure al disc",
"Not enough storage available" => "No hi ha prou espai disponible",
"Attempt to upload blacklisted file:" => "Intent de pujar un fitxer de la llista negra:",
"Error uploading contacts to storage." => "Error en carregar contactes a l'emmagatzemament.",
"Error moving file to imports folder." => "Error en moure el fitxer a la carpeta d'importació.",
"You do not have permissions to import into this address book." => "No teniu permisos per importar dins d'aquesta llibreta d'adreces.",
"File name missing from request." => "Falta el nom del fitxer en la petició.",
"Progress key missing from request." => "Falta la clau de progrés en la petició.",
"Attempt to access blacklisted file:" => "Intent d'accés a un fitxer de la llista negra:",
"No key is given." => "No heu facilitat cap clau.",
"No value is given." => "No heu facilitat cap valor.",
"Could not set preference: " => "No s'ha pogut establir la preferència:",
"Contact" => "Contacte",
"Other" => "Un altre",
"HomePage" => "Pàgina d'inici",
"Jabber" => "Jabber",
"Internet call" => "Trucada d'Internet",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Twitter",
"GoogleTalk" => "GoogleTalk",
"Facebook" => "Facebook",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"ownCloud" => "ownCloud",
"Work" => "Feina",
"Home" => "Casa",
"Mobile" => "Mòbil",
"Text" => "Text",
"Voice" => "Veu",
"Message" => "Missatge",
"Fax" => "Fax",
"Video" => "Vídeo",
"Pager" => "Paginador",
"Internet" => "Internet",
"Friends" => "Amics",
"Family" => "Familia",
"Enable LDAP Backend" => "Activa el rerefons LDAP",
"Enable LDAP backend for the contacts application" => "Activa el rerefons LDAP per a l'aplicació contactes",
"Warning: LDAP Backend is in beta mode, use with precautions" => "Compte: el rerefons LDAP és en mode beta, useu-lo amb precaució",
"New contact" => "Contacte nou",
"Group name" => "Nom del grup",
"New group" => "Grup nou",
"Address books" => "Llibretes d'adreces",
"Display name" => "Nom a mostrar",
"Add Address Book" => "Afegeix una llibreta d'adreces",
"Add LDAP Address Book" => "Afegeix llibreta d'adreces LDAP",
"Automatic format" => "Format automàtic",
"Select file..." => "Selecciona un fitxer...",
"(De-)select all" => "(Des-)selecciona'ls tots",
"Sort order" => "Ordena",
"First- Lastname" => "Nom- Congnom",
"Last-, Firstname" => "Cognom-, Nom",
"Delete" => "Esborra",
"Groups" => "Grups",
"Download" => "Baixa",
"Merge" => "Combina",
"Email" => "Correu electrònic",
"Phone" => "Telèfon",
"Address" => "Adreça",
"Group" => "Grup",
"Keyboard shortcuts" => "Dreceres de teclat",
"Navigation" => "Navegació",
"Next contact in list" => "Següent contacte de la llista",
"Previous contact in list" => "Contacte anterior de la llista",
"Expand/collapse current addressbook" => "Expandeix/col·lapsa la llibreta d'adreces",
"Next addressbook" => "Llibreta d'adreces següent",
"Previous addressbook" => "Llibreta d'adreces anterior",
"Actions" => "Accions",
"Refresh contacts list" => "Carrega de nou la llista de contactes",
"Add new contact" => "Afegeix un contacte nou",
"Add new addressbook" => "Afegeix una llibreta d'adreces nova",
"Delete current contact" => "Esborra el contacte",
"You have no contacts in your address book or your address book is disabled." => "No teniu contactes a la llibreta d'adreces o aquesta està desactivada.",
"Add a new contact or import existing contacts from a VCF file." => "Afegiu un contacte nou o importeu contactes existents des d'un fitxer VCF.",
"Which contact should the data be merged into?" => "A quin contacte li voleu combinar les dades?",
"Delete the other(s) after successful merge?" => "Elimino els altre(s) després d'una combinació satisfactòria?",
"Compose mail" => "Redacta un correu electrónic",
"Delete current photo" => "Elimina la foto actual",
"Edit current photo" => "Edita la foto actual",
"Upload new photo" => "Carrega una foto nova",
"Select photo from Files" => "Selecciona foto dels arxius",
"Favorite" => "Preferits",
"Name" => "Nom",
"First name" => "Nom",
"Additional names" => "Noms addicionals",
"Last name" => "Cognom",
"Address book" => "Agenda",
"Nickname" => "Sobrenom",
"Title" => "Títol",
"Organization" => "Organització",
"Birthday" => "Aniversari",
"Website" => "Pàgina web",
"Instant messaging" => "Missatgeria instantània",
"Notes go here..." => "Escriviu notes aquí...",
"Add field..." => "Afegeix camp...",
"Instant Messaging" => "Missatgeria instantània",
"Note" => "Nota",
"Web site" => "Adreça web",
"Preferred" => "Preferit",
"Please specify a valid email address." => "Especifiqueu una adreça de correu electrònic correcta",
"someone@example.com" => "algú@exemple.com",
"Mail to address" => "Envia per correu electrònic a l'adreça",
"Delete email address" => "Elimina l'adreça de correu electrònic",
"Enter phone number" => "Escriviu el número de telèfon",
"Go to web site" => "Vés a la web",
"View on map" => "Visualitza al mapa",
"Street address" => "Adreça",
"Postal code" => "Codi postal",
"City" => "Ciutat",
"State or province" => "Estat o província",
"Country" => "País",
"Instant Messenger" => "Instant Messenger",
"Active" => "Actiu",
"Share" => "Comparteix",
"Export" => "Exporta",
"CardDAV link" => "Enllaç CardDAV",
"Edit" => "Edita",
"Addressbook URI" => "URI de la llibreta d'adreces",
"URI" => "URI",
"Description" => "Descripció",
"LDAP URL" => "URL LDAP",
"Anonymous" => "Anònim",
"Read-only" => "Només de lectura",
"Read-Only" => "Només de lectura",
"User" => "Usuari",
"Password" => "Contrasenya",
"Page size" => "Mida de la pàgina",
"Base DN for search" => "DN base per la cerca",
"Base DN" => "DN Base",
"Search filter" => "Filtre de cerca",
"Filter" => "Filtre",
"Base DN for modification" => "DN Base per modificació",
"Base DN modification" => "modificació DN base",
"Connector" => "Connector",
"Connector value (Better use external editor and copy/paste)" => "Valor del connector (Millor utilitzar un editor extern i copiar/engaxar)",
"Copy from (Warning, replaces current custom value)" => "Copiar de (Avís, sobreescriu el valor personalitzat actual)"
);
